@@ -89,7 +89,7 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
-    env_vars = {k.upper():v for k,v in config.getenv.items()}
+    env_vars = {k.upper():v for k,v in config.getenv.items() if v}
     function = client.functions.create( 
         name=function_name, 
         folder=folder, 
