@@ -22,19 +22,19 @@ class EnvVar():
         envs = ["dev", "test", "prod"]
         if self.env not in envs:
             m = (f"Environment: allowed values are {envs}"
-                 f", got {self.env}")
+                 f", got '{self.env}'")
             raise ValueError(m)
 
         service_names = ["training", "prediction"]
         if self.service_name not in service_names:
             m = (f"Service name: allowed values are {service_names}"
-                 f", got {self.env}")
+                 f", got '{self.env}'")
             raise ValueError(m)
 
         local_deployments = ["True", None]
         if self.local_deployment not in local_deployments:
             m = (f"Local deployment: allowed values are {local_deployments}"
-                 f", got {self.env}")
+                 f", got '{self.env}'")
             raise ValueError(m)
 
 # Read environmental variables
