@@ -12,7 +12,7 @@ import akerbp.mlops.model_manager as mm
 from akerbp.mlops.deployment import helpers
 from akerbp.mlops.core import logger, config
 logging=logger.get_logger(name='MLOps')
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 
 
 def deploy_model(model_settings):
