@@ -89,7 +89,7 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    envs = [f"{k.upper()}={v}" for k,v in config.getenv.items()]
+    envs = [f"{k.upper()}={v}" for k,v in config.getenv.items() if v]
     env_list_string=','.join(envs)
     
     subprocess.check_call(
