@@ -16,7 +16,7 @@ ModelException = model_module.ModelException
 import akerbp.mlops.model_manager as mm
 from akerbp.mlops import __version__ as version
 from akerbp.mlops.core import config, logger 
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 
 logging=logger.get_logger()
 
